<template>
    <el-dialog
        :title="`私有云资源申请${typeText}`"
        :visible.sync="visible"
        width="600px"
        :before-close="handleClose"
        append-to-body
        top="8vh"
    >
        <el-form
            v-form
            data-vv-scope="approvalform"
            ref="approvalform"
            :model="approvalform"
            label-width="100px"
            :rules="rules"
        >
            <template>
                <el-row>
                    <el-col :span="24" v-if="type === 'start' || type === 'agree'">
                        <el-form-item
                            :label="type === 'agree' ? '执行人' : '审核人'"
                            prop="approvalUserName"
                        >
                            <eip-user-selector
                                v-model="approvalform.approvalUserName"
                                append-to-body
                                :single="true"
                                :config="{
                                    id: 'approvalform.approvalUserId',
                                    fullname: 'approvalform.approvalUserName',
                                    account: 'approvalform.approvalUserAccount',
                                }"
                                :placeholder="
                                    type === 'agree' ? '请选择执行人' : '请选择审核人'
                                "
                            />
                        </el-form-item>
                    </el-col>
                    <el-col :span="24" v-if="type !== 'start' && type !== 'complete'">
                        <el-form-item label="审核意见" prop="intranetPort">
                            <el-input
                                type="textarea"
                                v-model="approvalform.intranetPort"
                                placeholder="请输入审核意见"
                                clearable
                            />
                        </el-form-item>
                    </el-col>
                    <el-col :span="24" v-if="type !== 'start'">
                        <el-form-item label="附件">
                            <file-upload
                                v-if="visible"
                                :dadToSon="dadToSon"
                                @sonToDad="handleFileChange"
                            ></file-upload>
                        </el-form-item>
                    </el-col>
                </el-row>
            </template>
        </el-form>
        <div slot="footer" class="dialog-footer">
            <el-button @click="handleClose" :loading="loading">取 消</el-button>
            <el-button type="primary" @click="handleSubmit" :loading="loading"
                >确定</el-button
            >
        </div>
    </el-dialog>
</template>
<script>
import _ from 'lodash'
import api from './../js/api.js'
import eipUserSelector from '@/components/eipControl/selector/EipUserSelector.vue'
import fileUpload from '@/components/upload/fileListUpload.vue'
export default {
    name: 'applyApproval',
    components: {
        fileUpload,
        eipUserSelector,
    },
    props: {
        startApproval: {
            type: Boolean,
            default: false,
        },
    },
    data() {
        return {
            visible: false,
            loading: false,
            type: '',
            approvalform: {
                privateCloudApplyId: '',
                applyRecordFile: [],
                approvalResult: null,
            },
            dadToSon: {
                bizPath: 'resourceApply',
                fileList: [],
            },
            rules: {
                approvalUserName: {
                    required: true,
                    message: '请选择审核人',
                    trigger: 'blur',
                },
                intranetPort: {
                    required: true,
                    message: '请输入审核意见',
                    trigger: 'change',
                },
            },
            typeText: '',
        }
    },
    mounted() {},
    methods: {
        handleOpen(type, id) {
            this.type = type
            if (this.type === 'start') {
                this.typeText = '发起审核'
                this.approvalform.approvalResult = 3
            } else if (this.type === 'reject') {
                this.typeText = '审核驳回'
                this.approvalform.approvalResult = 0
            } else if (this.type === 'agree') {
                this.typeText = '审核同意'
                this.approvalform.approvalResult = 1
            } else if (this.type === 'complete') {
                this.typeText = '审核完成'
                this.approvalform.approvalResult = 4
            }
            this.approvalform.privateCloudApplyId = id
            this.visible = true
        },
        handleFileChange(data) {
            this.approvalform.applyRecordFile = data
        },
        handleClose() {
            this.typeText = ''
            this.approvalform = {
                privateCloudApplyId: '',
                applyRecordFile: [],
                approvalResult: null,
            }
            this.visible = false
        },
        handleSubmit() {
            this.$refs.approvalform.validate((bool, object) => {
                if (bool) {
                    this.$confirm(`确定${this.typeText}吗？`, '提示', {
                        confirmButtonText: '确定',
                        cancelButtonText: '取消',
                        type: 'warning',
                    }).then(() => {
                        this.loading = true
                        api.applyApproval(this.type, this.approvalform)
                            .then((res) => {
                                if (res.state) {
                                    this.$message({
                                        message: `${this.typeText}成功`,
                                        type: 'success',
                                    })
                                } else {
                                    this.$message({
                                        message: res.message,
                                        type: 'warning',
                                    })
                                }
                                this.$emit('close')
                                this.handleClose()
                            })
                            .catch((err) => {
                                this.$message({
                                    message: err,
                                    type: 'warning',
                                })
                            })
                            .finally(() => {
                                this.loading = false
                            })
                    })
                } else {
                    this.$message.warning(
                        `有${
                            Object.keys(object).length
                        }个字段未通过校验，请正确填写表单内容。`
                    )
                }
            })
        },
    },
}
</script>
<style lang="scss" scoped>

/deep/ .el-input input{
    height: 33px!important;
    line-height: 33px!important;
}
/deep/ .el-form{
    background-color: transparent;
}
</style>
